CREATE TABLE WAITLIST_STATUS (
  ID_WAITLIST_STATUS NUMBER,
  DESCRIPTION VARCHAR2(200 CHAR),
  INTERNAL_DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT WAITLIST_STATUS_PK PRIMARY KEY (ID_WAITLIST_STATUS)
);

CREATE SEQUENCE WAITLIST_STATUS_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 100 NOCACHE NOORDER  NOCYCLE;

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (1, 'Open', 'Open', 'Y');

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (2, 'Completed', 'Completed', 'Y');

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (3, 'Follow up', 'Follow up', 'Y');

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (-1, 'Deleted', 'Deleted', 'Y');

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (-2, 'Cancelled', 'Cancelled', 'Y');

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (-3, 'Cancelled reservation', 'Cancelled reservation', 'Y');

INSERT INTO WAITLIST_STATUS (ID_WAITLIST_STATUS, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) 
VALUES (-4, 'Cancelled contract', 'Cancelled contract', 'Y');

ALTER TABLE WAITLIST
ADD CONSTRAINT WAITLIST_STATUS_FK
FOREIGN KEY (STATUS)
REFERENCES WAITLIST_STATUS(ID_WAITLIST_STATUS);

DROP VIEW V_WAITLIST;

CREATE OR REPLACE VIEW V_WAITLIST AS (
SELECT W.ID_WAITLIST, W.NNLOCATION_ID, W.ID_LASTNIKA, W.ID_PLOVILA, W.ID_TYPE, W.AREA, W.ID_PRIVEZ, W.DATE_FROM, W.DATE_TO, W.LENGTH_OF_STAY, W.STATUS, W.DATE_CREATED, W.USER_CREATED, W.DATE_CHANGED, W.USER_CHANGED, W.USER_COMMENT,
WT.DESCRIPTION AS TYPE_DESCRIPTION, WT.COLOR AS TYPE_COLOR, WT.TEXT_COLOR AS TYPE_TEXT_COLOR, WTS.DESCRIPTION AS STATUS_DESCRIPTION,
P.IME AS BOAT_NAME, NT.OPIS AS BOAT_TYPE, P.DOLZINA AS BOAT_LENGTH, P.SIRINA AS BOAT_WIDTH, P.GREZ AS BOAT_DRAUGHT, W.BERTH_LENGTH_DESC, NO.OPIS AS AREA_DESCRIPTION, NP.N_PRIVEZA AS BERTH_DESCRIPTION,
(CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (K.IME || ' ' || K.PRIIMEK) ELSE (K.PRIIMEK || ' ' || K.IME) END) AS OWNER, 
VK.OPIS AS OWNER_TYPE_DESCRIPTION, W.OWNER_TYPE AS OWNER_TYPE, VS.OPIS AS OWNER_SUBTYPE_DESCRIPTION, K.SUBTYPE AS OWNER_SUBTYPE, K.TELEX AS OWNER_MOBILE_PHONE
FROM WAITLIST W
LEFT OUTER JOIN WAITLIST_TYPE WT ON WT.ID_WAITLIST_TYPE = W.ID_TYPE
LEFT OUTER JOIN WAITLIST_STATUS WTS ON WTS.ID_WAITLIST_STATUS = W.STATUS
LEFT OUTER JOIN PLOVILA P ON P.ID = W.ID_PLOVILA
LEFT OUTER JOIN KUPCI K ON K.ID = W.ID_LASTNIKA
LEFT OUTER JOIN NNOBJEKT NO ON NO.SIFRA = W.AREA
LEFT OUTER JOIN NNPRIVEZ NP ON NP.ID_PRIVEZ = W.ID_PRIVEZ 
LEFT OUTER JOIN NNTIP NT ON NT.SIFRA = P.NTIP
LEFT OUTER JOIN NNVRSKUP VK ON VK.SIFRA = W.OWNER_TYPE
LEFT OUTER JOIN NNVRSKUP VS ON VS.SIFRA = K.SUBTYPE
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (2096, SYSDATE, '5.5', 2016, 'Waitlist status')
;